"""
.. module:: InitDMP

********************************
InitDMP: módulo de inicializción
********************************

Este módulo inicializa dispositivos y ajusta settings iniciales.

Consta de las siguientes funciones:

"""


import LogoDMP as DMP
import timers


## Inicialización comm serie


def init_settings(hexi):
    """
    
.. py:function:: init_settings(hexi)
    
    Inicializa el hardware ajustando los settings iniciales tras arrancado y presenta logotipos en pantalla OLED de la UOC además del propio del DMP

    :param hexi(*hexiwear*): Objeto Hexiwear para acceso a sus métodos 

    """
    # Muestra logo UOC

 #   hexi.draw_image(UOC.LogoUoc, 32, 32, 32, 32)
    
    #hexi.vibration(100)
    sleep(3000)
    # Muestra logo DMP
    print("DMP")
    hexi.draw_image(DMP.LogoDMP, 8, 8, 80, 80)
    sleep(3000)
    hexi.clear_display()
    sleep(1000)
    return
    
def pressed_up(hexi):
    """
    
.. py:function:: pressed_up(hexi)
    
    Detecta pulsación del botón UP

    :param hexi(*hexiwear*): Objeto Hexiwear para acceso a sus métodos 

    """
    hexi.vibration(100)


def pressed_down(hexi):
    """
    
.. py:function:: pressed_down(hexi)
    
    Detecta pulsación del botón DOWN

    :param hexi(*hexiwear*): Objeto Hexiwear para acceso a sus métodos 

    """    
    hexi.vibration(100)


def toggle_ble(hexi):
    """
    
.. py:function:: toggle_ble(hexi)
    
    Toggle de la capacidad BLE (Kinetis)

    :param hexi(*hexiwear*): Objeto Hexiwear para acceso a sus métodos 

    """    
    try:
        print("Left Button Pressed")
        hexi.vibration(100)
        hexi.bt_driver.toggle_adv_mode()
    except Exception as e:
        print("error on left_pressed", e)


def get_sensors(hexi, sens_conf):
    """
    
.. py:function:: get_sensors(hexi)
    
    Adquiere datos de los sensores onboard

    :param get_sensors(*hexiwear*): Objeto Hexiwear para acceso a sus métodos 

    """

    
    bl, chg = hexi.get_battery_level(chg_state=True)
    al = hexi.get_ambient_light() if sens_conf['tlum'] == "on" else False
    temp = hexi.get_temperature() if sens_conf['ttemp'] == "on" else False
    humid = hexi.get_humidity() if sens_conf['thumid'] == "on" else False
    press = hexi.get_pressure() if sens_conf['tpress'] == "on" else False

    dict_sens = {'bat_level': bl, 'bat_stat' : chg, 'light_ambient' : al, 'temperature' : temp,'humidity' : humid, 'pressure' : press }
    mimu = {}
    # Captura secuencia de valores de Acc, Giro, Magnetometer
    # F = 1 KHz
    for i in range(int(sens_conf['mimu_items'])):
        acc = hexi.get_accelerometer_data()
        magn = hexi.get_magnetometer_data()
        giro = hexi.get_gyroscope_data()
        temp = timers.now()
        mimu[i] = {'acc' : acc, 'magn' : magn, 'giro' : giro, 'time' : temp}
        sleep(int(sens_conf['mimu_period']))
        
    #Integra datos en un diccionario
    dict_sens['mimu'] = mimu
    
    return dict_sens
    
    